import getProducer from "~/server/actions/getProducer";

export default async function WineProducer(props: { id: string }) {
  const { id } = props;

  // Validate the id before making the database call
  if (!id) {
    return <p>Invalid producer ID</p>;
  }

  try {
    const result = await getProducer(id);
    return !result ? <p>Unable to retrieve producer</p> : <p>{result?.name}</p>;
  } catch (error) {
    console.error("Error fetching producer:", error);
    return <p>Error fetching producer</p>;
  }
}

// Utility function to validate UUID
function isValidUUID(uuid: string) {
  const uuidRegex =
    /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i;
  return uuidRegex.test(uuid);
}
